@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
  *
- $Id: properties.c,v 1.50 2005/07/09 05:48:58 ryanl Exp $
+ $Id: properties.c,v 1.51 2005/11/16 15:50:37 davyd Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -252,11 +252,12 @@ prop_cb (BonoboUIComponent *uic,
 	 const char        *verb)
 {
   GladeXML  *glade_xml;
-  GtkWidget *layout_table, *combo_ptr, *spin_ptr;
+  GtkWidget *combo_ptr, *spin_ptr;
   GConfClient *client;
   GtkListStore *liststore;
   GtkCellRenderer *renderer;
   GtkTreeIter iter;
+  /* Shouldn't this be used for something later on? */
   gboolean   inhibit_command_line;
 
   client = gconf_client_get_default ();
@@ -354,8 +355,6 @@ prop_cb (BonoboUIComponent *uic,
 		    TRUE);
   }
 
-  layout_table = glade_xml_get_widget (glade_xml, "layout_table");
-
   battstat->radio_traditional_battery = glade_xml_get_widget (glade_xml,
 		  "battery_view_2");
   g_signal_connect (G_OBJECT (battstat->radio_traditional_battery), "toggled",
